pub struct Command {
pub list: bool,
pub build: Cmd,
pub build_clients: bool,
pub build_clients_args: Args,
}Expand description
Build a contract from source
Builds all crates that are referenced by the cargo manifest (Cargo.toml) that have cdylib as their crate-type. Crates are built for the wasm32 target. Unless configured otherwise, crates are built with their default features and with their release profile.
To view the commands that will be executed, without executing them, use the –print-commands-only option.
Fields
list: boolList package names in order of build
build: Cmdbuild_clients: boolBuild client code in addition to building the contract
build_clients_args: ArgsImplementations